@@ -48,12 +48,10 @@
   se
 }
 
-#' @importFrom stats model.matrix terms vcov formula
-#' @importFrom dplyr arrange
-#' @importFrom rlang parse_expr
+#' @importFrom stats model.matrix terms formula
 #' @importFrom purrr map flatten_chr map_lgl map2
 #' @importFrom sjmisc is_empty
-#' @importFrom insight find_random clean_names find_parameters
+#' @importFrom insight find_random clean_names find_parameters get_varcov
 .safe_se_from_vcov <- function(model,
                               fitfram,
                               typical,
@@ -133,21 +131,24 @@
   # sort data by grouping levels, so we have the correct order
   # to slice data afterwards
   if (length(terms) > 2) {
-    trms <- rlang::parse_expr(terms[3])
-    newdata <- dplyr::arrange(newdata, !!trms)
-    fitfram <- dplyr::arrange(fitfram, !!trms)
+    trms <- terms[3]
+    newdata <- newdata[order(newdata[[trms]]), ]
+    fitfram <- fitfram[order(fitfram[[trms]]), ]
   }
 
   if (length(terms) > 1) {
-    trms <- rlang::parse_expr(terms[2])
-    newdata <- dplyr::arrange(newdata, !!trms)
-    fitfram <- dplyr::arrange(fitfram, !!trms)
+    trms <- terms[2]
+    newdata <- newdata[order(newdata[[trms]]), ]
+    fitfram <- fitfram[order(fitfram[[trms]]), ]
   }
 
-  trms <- rlang::parse_expr(terms[1])
-  newdata <- dplyr::arrange(newdata, !!trms)
-  fitfram <- dplyr::arrange(fitfram, !!trms)
+  trms <- terms[1]
+  newdata <- newdata[order(newdata[[trms]]), ]
+  fitfram <- fitfram[order(fitfram[[trms]]), ]
 
+  # rownames were resorted as well, which causes troubles in model.matrix
+  rownames(newdata) <- NULL
+  rownames(fitfram) <- NULL
 
   # check if robust vcov-matrix is requested
   if (!is.null(vcov.fun)) {
@@ -158,23 +159,7 @@
     vcm <- as.matrix(do.call(vcov.fun, c(list(x = model, type = vcov.type), vcov.args)))
   } else {
     # get variance-covariance-matrix, depending on model type
-    if (is.null(model.class)) {
-      vcm <- as.matrix(stats::vcov(model))
-    } else if (model.class %in% c("hurdle", "zeroinfl", "zerotrunc")) {
-      vcm <- as.matrix(stats::vcov(model, model = "count"))
-    } else if (model.class == "betareg") {
-      vcm <- as.matrix(stats::vcov(model, model = "mean"))
-    } else if (model.class == "truncreg") {
-      vcm <- as.matrix(stats::vcov(model))
-      # remove sigma from matrix
-      vcm <- vcm[1:(nrow(vcm) - 1), 1:(ncol(vcm) - 1)]
-    } else if (model.class == "gamlss") {
-      vc <- suppressWarnings(stats::vcov(model))
-      cond_pars <- length(insight::find_parameters(model)$conditional)
-      vcm <- as.matrix(vc)[1:cond_pars, 1:cond_pars]
-    } else {
-      vcm <- as.matrix(stats::vcov(model))
-    }
+    vcm <- insight::get_varcov(model, component = "conditional")
   }
 
 
@@ -233,7 +218,7 @@
 
   mm <- mm[mm.rows, ]
 
-  if (!is.null(model.class) && model.class %in% c("polr", "multinom")) {
+  if (!is.null(model.class) && model.class %in% c("polr", "multinom", "brmultinom", "bracl")) {
     keep <- intersect(colnames(mm), colnames(vcm))
     vcm <- vcm[keep, keep]
     mm <- mm[, keep]
