@@ -1,4 +1,4 @@
-.set_attributes_and_class <- function(data, model, t.title, x.title, y.title, l.title, legend.labels, x.axis.labels, faminfo, x.is.factor, constant.values = NULL, terms = NULL, ori.terms = NULL, at.list = NULL, n.trials = NULL, prediction.interval = NULL) {
+.set_attributes_and_class <- function(data, model, t.title, x.title, y.title, l.title, legend.labels, x.axis.labels, faminfo, constant.values = NULL, terms = NULL, ori.terms = NULL, at.list = NULL, n.trials = NULL, prediction.interval = NULL, condition = NULL) {
   # check correct labels
   if (!is.null(x.axis.labels) && length(x.axis.labels) != length(stats::na.omit(unique(data$x))))
     x.axis.labels <- as.vector(sort(stats::na.omit(unique(data$x))))
@@ -15,12 +15,12 @@
   attr(data, "legend.title") <- l.title
   attr(data, "legend.labels") <- legend.labels
   attr(data, "x.axis.labels") <- x.axis.labels
-  attr(data, "x.is.factor") <- x.is.factor
   attr(data, "constant.values") <- constant.values
   attr(data, "terms") <- terms
   attr(data, "ori.terms") <- ori.terms
   attr(data, "at.list") <- at.list
   attr(data, "prediction.interval") <- prediction.interval
+  attr(data, "condition") <- condition
 
   # remember fit family
   attr(data, "family") <- faminfo$family
